@@ -1,4 +1,4 @@
-require File.expand_path('../helper', __FILE__)
+require File.expand_path("../helper", __FILE__)
 
 class TestRakeLateTime < Rake::TestCase
   def test_late_time_comparisons
@@ -13,6 +13,6 @@ class TestRakeLateTime < Rake::TestCase
   end
 
   def test_to_s
-    assert_equal '<LATE TIME>', Rake::LATE.to_s
+    assert_equal "<LATE TIME>", Rake::LATE.to_s
   end
 end
