@@ -1,5 +1,5 @@
-require File.expand_path('../helper', __FILE__)
-require 'fileutils'
+require File.expand_path("../helper", __FILE__)
+require "fileutils"
 
 class TestRakeTask < Rake::TestCase
   include Rake
@@ -33,13 +33,13 @@ class TestRakeTask < Rake::TestCase
   end
 
   def test_inspect
-    t = task(:foo => [:bar, :baz])
+    t = task(foo: [:bar, :baz])
     assert_equal "<Rake::Task foo => [bar, baz]>", t.inspect
   end
 
   def test_invoke
     runlist = []
-    t1 = task(:t1 => [:t2, :t3]) { |t| runlist << t.name; 3321 }
+    t1 = task(t1: [:t2, :t3]) { |t| runlist << t.name; 3321 }
     task(:t2) { |t| runlist << t.name }
     task(:t3) { |t| runlist << t.name }
     assert_equal ["t2", "t3"], t1.prerequisites
@@ -49,8 +49,8 @@ class TestRakeTask < Rake::TestCase
 
   def test_invoke_with_circular_dependencies
     runlist = []
-    t1 = task(:t1 => [:t2]) { |t| runlist << t.name; 3321 }
-    t2 = task(:t2 => [:t1]) { |t| runlist << t.name }
+    t1 = task(t1: [:t2]) { |t| runlist << t.name; 3321 }
+    t2 = task(t2: [:t1]) { |t| runlist << t.name }
     assert_equal ["t2"], t1.prerequisites
     assert_equal ["t1"], t2.prerequisites
     ex = assert_raises RuntimeError do
@@ -87,8 +87,8 @@ class TestRakeTask < Rake::TestCase
 
   def test_no_double_invoke
     runlist = []
-    t1 = task(:t1 => [:t2, :t3]) { |t| runlist << t.name; 3321 }
-    task(:t2 => [:t3]) { |t| runlist << t.name }
+    t1 = task(t1: [:t2, :t3]) { |t| runlist << t.name; 3321 }
+    task(t2: [:t3]) { |t| runlist << t.name }
     task(:t3) { |t| runlist << t.name }
     t1.invoke
     assert_equal ["t3", "t2", "t1"], runlist
@@ -112,29 +112,30 @@ class TestRakeTask < Rake::TestCase
 
   def test_clear
     desc "a task"
-    t = task("t" => "a") { }
+    t = task("t", ["b"] => "a") {}
     t.clear
     assert t.prerequisites.empty?, "prerequisites should be empty"
     assert t.actions.empty?, "actions should be empty"
     assert_nil t.comment, "comments should be empty"
+    assert_empty t.arg_names, "arg names should be empty"
   end
 
   def test_clear_prerequisites
     t = task("t" => ["a", "b"])
-    assert_equal ['a', 'b'], t.prerequisites
+    assert_equal ["a", "b"], t.prerequisites
     t.clear_prerequisites
     assert_equal [], t.prerequisites
   end
 
   def test_clear_actions
-    t = task("t") { }
+    t = task("t") {}
     t.clear_actions
     assert t.actions.empty?, "actions should be empty"
   end
 
   def test_clear_comments
     desc "the original foo"
-    task :foo => [:x] do
+    task foo: [:x] do
       # Dummy action
     end
 
@@ -148,6 +149,18 @@ class TestRakeTask < Rake::TestCase
     assert_equal 1, task(:foo).actions.size
   end
 
+  def test_clear_args
+    task :foo, [:x] do
+      # Dummy action
+    end
+
+    task(:foo).clear_args
+
+    task :foo
+
+    assert_empty task(:foo).arg_names
+  end
+
   def test_find
     task :tfind
     assert_equal "tfind", Task[:tfind].name
@@ -164,8 +177,8 @@ class TestRakeTask < Rake::TestCase
   def test_multi_invocations
     runs = []
     p = proc do |t| runs << t.name end
-    task({ :t1 => [:t2, :t3] }, &p)
-    task({ :t2 => [:t3] }, &p)
+    task({ t1: [:t2, :t3] }, &p)
+    task({ t2: [:t3] }, &p)
     task(:t3, &p)
     Task[:t1].invoke
     assert_equal ["t1", "t2", "t3"], runs.sort
@@ -173,8 +186,8 @@ class TestRakeTask < Rake::TestCase
 
   def test_task_list
     task :t2
-    task :t1 => [:t2]
-    assert_equal ["t1", "t2"], Task.tasks.map { |t| t.name }
+    task t1: [:t2]
+    assert_equal ["t1", "t2"], Task.tasks.map(&:name)
   end
 
   def test_task_gives_name_on_to_s
@@ -183,34 +196,34 @@ class TestRakeTask < Rake::TestCase
   end
 
   def test_symbols_can_be_prerequisites
-    task :a => :b
+    task a: :b
     assert_equal ["b"], Task[:a].prerequisites
   end
 
   def test_strings_can_be_prerequisites
-    task :a => "b"
+    task a: "b"
     assert_equal ["b"], Task[:a].prerequisites
   end
 
   def test_arrays_can_be_prerequisites
-    task :a => ["b", "c"]
+    task a: ["b", "c"]
     assert_equal ["b", "c"], Task[:a].prerequisites
   end
 
   def test_filelists_can_be_prerequisites
-    task :a => FileList.new.include("b", "c")
+    task a: FileList.new.include("b", "c")
     assert_equal ["b", "c"], Task[:a].prerequisites
   end
 
   def test_prerequisite_tasks_returns_tasks_not_strings
-    a = task :a => ["b", "c"]
+    a = task a: ["b", "c"]
     b = task :b
     c = task :c
     assert_equal [b, c], a.prerequisite_tasks
   end
 
   def test_prerequisite_tasks_fails_if_prerequisites_are_undefined
-    a = task :a => ["b", "c"]
+    a = task a: ["b", "c"]
     task :b
     assert_raises(RuntimeError) do
       a.prerequisite_tasks
@@ -221,7 +234,7 @@ class TestRakeTask < Rake::TestCase
     task :b
     a = b = nil
     namespace "X" do
-      a = task :a => ["b", "c"]
+      a = task a: ["b", "c"]
       b = task :b
     end
     c = task :c
@@ -232,7 +245,7 @@ class TestRakeTask < Rake::TestCase
   def test_prerequisite_tasks_finds_tasks_with_same_name_outside_namespace
     b1 = nil
     namespace "a" do
-      b1 = task :b => "b"
+      b1 = task b: "b"
     end
     b2 = task :b
 
@@ -246,11 +259,11 @@ class TestRakeTask < Rake::TestCase
       a_m = task :m
 
       namespace "b" do
-        a_b_m = task :m => "m"
+        a_b_m = task m: "m"
       end
 
       namespace "c" do
-        a_c_m = task :m => "a:m"
+        a_c_m = task m: "a:m"
       end
     end
 
@@ -259,9 +272,9 @@ class TestRakeTask < Rake::TestCase
   end
 
   def test_all_prerequisite_tasks_includes_all_prerequisites
-    a = task :a => "b"
-    b = task :b => ["c", "d"]
-    c = task :c => "e"
+    a = task a: "b"
+    b = task b: ["c", "d"]
+    c = task c: "e"
     d = task :d
     e = task :e
 
@@ -269,30 +282,30 @@ class TestRakeTask < Rake::TestCase
   end
 
   def test_all_prerequisite_tasks_does_not_include_duplicates
-    a = task :a => ["b", "c"]
-    b = task :b => "c"
+    a = task a: ["b", "c"]
+    b = task b: "c"
     c = task :c
 
     assert_equal [b, c], a.all_prerequisite_tasks.sort_by { |t| t.name }
   end
 
   def test_all_prerequisite_tasks_includes_self_on_cyclic_dependencies
-    a = task :a => "b"
-    b = task :b => "a"
+    a = task a: "b"
+    b = task b: "a"
 
     assert_equal [a, b], a.all_prerequisite_tasks.sort_by { |t| t.name }
   end
 
   def test_timestamp_returns_now_if_all_prereqs_have_no_times
-    a = task :a => ["b", "c"]
+    a = task a: ["b", "c"]
     task :b
     task :c
 
-    assert_in_delta Time.now, a.timestamp, 0.1, 'computer too slow?'
+    assert_in_delta Time.now, a.timestamp, 0.1, "computer too slow?"
   end
 
   def test_timestamp_returns_latest_prereq_timestamp
-    a = task :a => ["b", "c"]
+    a = task a: ["b", "c"]
     b = task :b
     c = task :c
 
@@ -300,7 +313,7 @@ class TestRakeTask < Rake::TestCase
     def b.timestamp() Time.now + 10 end
     def c.timestamp() Time.now + 5 end
 
-    assert_in_delta now, a.timestamp, 0.1, 'computer too slow?'
+    assert_in_delta now, a.timestamp, 0.1, "computer too slow?"
   end
 
   def test_always_multitask
@@ -316,27 +329,27 @@ class TestRakeTask < Rake::TestCase
       mx.synchronize { result << t.name }
     end
 
-    t_c = task(:c => [:a, :b]) do |t|
+    t_c = task(c: [:a, :b]) do |t|
       mx.synchronize { result << t.name }
     end
 
     t_c.invoke
 
     # task should always run in order
-    assert_equal ['a', 'b', 'c'], result
+    assert_equal ["a", "b", "c"], result
 
-    [t_a, t_b, t_c].each { |t| t.reenable }
+    [t_a, t_b, t_c].each(&:reenable)
     result.clear
 
     Rake.application.options.always_multitask = true
     t_c.invoke
 
     # with multitask, task 'b' should grab the mutex first
-    assert_equal ['b', 'a', 'c'], result
+    assert_equal ["b", "a", "c"], result
   end
 
   def test_investigation_output
-    t1 = task(:t1 => [:t2, :t3]) { |t| runlist << t.name; 3321 }
+    t1 = task(t1: [:t2, :t3]) { |t| runlist << t.name; 3321 }
     task(:t2)
     task(:t3)
     out = t1.investigation
@@ -384,13 +397,13 @@ class TestRakeTask < Rake::TestCase
 
   def test_comments_do_not_set
     t = task(:t, :name, :rev)
-    assert_equal nil, t.comment
+    assert_nil t.comment
   end
 
   def test_comments_is_nil
     t = task(:t, :name, :rev)
     t.comment = nil
-    assert_equal nil, t.comment
+    assert_nil t.comment
   end
 
   def test_extended_comments
@@ -436,7 +449,7 @@ class TestRakeTask < Rake::TestCase
   end
 
   def test_source_is_first_prerequisite
-    t = task :t => ["preqA", "preqB"]
+    t = task t: ["preqA", "preqB"]
     assert_equal "preqA", t.source
   end
 end
