@@ -1,11 +1,11 @@
-require File.expand_path('../helper', __FILE__)
+require File.expand_path("../helper", __FILE__)
 
 class TestRakeTaskManagerArgumentResolution < Rake::TestCase
 
   def test_good_arg_patterns
     assert_equal [:t, [], []],       task(:t)
-    assert_equal [:t, [], [:x]],     task(:t => :x)
-    assert_equal [:t, [], [:x, :y]], task(:t => [:x, :y])
+    assert_equal [:t, [], [:x]],     task(t: :x)
+    assert_equal [:t, [], [:x, :y]], task(t: [:x, :y])
 
     assert_equal [:t, [:a, :b], []],       task(:t, [:a, :b])
     assert_equal [:t, [:a, :b], [:x]],     task(:t, [:a, :b] => :x)
